---
layout: graph
title: Repository Issues
---

<svg id="repos_issues"></svg>
<script src="{{ site.baseurl }}/assets/js/extractors/repos_issues.js"></script>

<script>
$(document).ready(function(){
  draw_scatter_repo_issues('#repos_issues');
})
</script>
